from django.db import models
from django.utils.translation import gettext_lazy as _

from storages.backends.s3boto3 import S3Boto3Storage

from .utils import asset_upload


class BaseModel(models.Model):
    updated = models.DateTimeField(_('updated'), auto_now=True, db_index=True)
    created = models.DateTimeField(_('created'), auto_now_add=True, db_index=True)

    class Meta:
        abstract = True


class Video(BaseModel):
    title = models.CharField(_('full name'), max_length=255)
    description = models.TextField(_('description'), blank=True, null=True)
    local_file = models.FileField(
        'local file',
        upload_to='videos',
        blank=True,
        null=True,
    )
    s3_file = models.FileField(
        'AWS S3 file',
        storage=S3Boto3Storage(bucket_name='clutchpoints-videos'),
        blank=True,
        null=True,
        max_length=500,
    )
    thumbnail = models.ImageField(
        'thumbnail',
        upload_to=asset_upload,
        storage=S3Boto3Storage(bucket_name='clutchpoints-videos'),
        blank=True,
        null=True,
        max_length=500,
    )

    class Meta:
        ordering = ('title',)

    def __str__(self):
        return self.title


class Playlist(BaseModel):
    title = models.CharField(_('title'), max_length=255)
    description = models.TextField(_('description'), blank=True, null=True)
    videos = models.ManyToManyField(Video, related_name='playlist')

    class Meta:
        ordering = ('title',)

    def __str__(self):
        return self.title
